==> tuain-ecosystem-lib-0.1.4.tgz: package/lib/ecosystem/users.js <==
const USERS_COLLECTION = 'Users';
const STORES_COLLECTION = 'Stores';

const moduleErrors = {
  store: {
    notFound: ['01', 'No se encontró sucursal que se ajuste a la búsqueda'],
  },
};

class UserManager {
  constructor(getDb, logger, errMgr, userQueries) {
    this.getDb = getDb;
    this.logger = logger;
    this.errMgr = errMgr;
    this.userQueries = userQueries;
    this.errMgr.addModuleSet('users', moduleErrors);
  }

  async getStoreUsers(reqData) {
    const { storeId } = reqData;
    const storeCol = this.getDb().collection(STORES_COLLECTION);
    const store = await storeCol.findOne(this.userQueries.findById(storeId), { users: 1 });
    if (!store) {
      const errorDetail = `Sucursal con Id ${storeId} no encontrado`;
      const errorObj = this.errMgr.get(moduleErrors.store.notFound, errorDetail);
      return [errorObj, null];
    }
    return [null, store];
  }

  async addStoreUser(reqData) {
    const { storeId, userId } = reqData;
    const storesCol = this.getDb().collection(STORES_COLLECTION);
    const store = await storesCol.findOne(this.userQueries.findById(storeId), { users: 1 });
    if (!store) {
      const errorDetail = `Sucursal con Id ${storeId} no encontrado`;
      const errorObj = this.errMgr.get(moduleErrors.store.notFound, errorDetail);
      return [errorObj, null];
    }
    const updateResult = await storesCol.updateOne(
      this.userQueries.findById(storeId),
      this.userQueries.addUser(userId),
    );
    const result = (updateResult?.result?.nModified > 0);
    return [null, { result }];
  }
}

module.exports = UserManager;

==> tuain-ecosystem-lib-0.1.92.tgz: package/lib/ecosystem/users.js <==
const THIRDPARTY_COLLECTION = 'ThirdParties';
const STORES_COLLECTION = 'Stores';

const moduleErrors = {
  store: {
    notFound: ['01', 'No se encontró sucursal que se ajuste a la búsqueda'],
  },
};

class UserManager {
  constructor(getDb, logger, errMgr, userQueries) {
    this.getDb = getDb;
    this.logger = logger;
    this.errMgr = errMgr;
    this.userQueries = userQueries;
    this.errMgr.addModuleSet('users', moduleErrors);
  }

  async getStoreUsers(reqData) {
    const { storeId } = reqData;
    const storeCol = this.getDb().collection(STORES_COLLECTION);
    const store = await storeCol.findOne(this.userQueries.findById(storeId), { users: 1 });
    if (!store) {
      const errorDetail = `Sucursal con Id ${storeId} no encontrado`;
      const errorObj = this.errMgr.get(moduleErrors.store.notFound, errorDetail);
      return [errorObj, null];
    }
    return [null, store];
  }

  async addStoreUser(reqData) {
    const { storeId, userId } = reqData;
    const storesCol = this.getDb().collection(STORES_COLLECTION);
    const store = await storesCol.findOne(this.userQueries.findById(storeId));
    if (!store) {
      const errorDetail = `Sucursal con Id ${storeId} no encontrada`;
      const errorObj = this.errMgr.get(moduleErrors.store.notFound, errorDetail);
      return [errorObj, null];
    }
    const updateResult = await storesCol.updateOne(
      this.userQueries.findById(storeId),
      this.userQueries.addUser(userId),
    );
    const result = (updateResult?.result?.nModified > 0);
    return [null, { result }];
  }

  async removeStoreUser(reqData) {
    const { storeId, userId } = reqData;
    const storesCol = this.getDb().collection(STORES_COLLECTION);
    const store = await storesCol.findOne(this.userQueries.findById(storeId));
    if (!store) {
      const errorDetail = `Sucursal con Id ${storeId} no encontrada`;
      const errorObj = this.errMgr.get(moduleErrors.store.notFound, errorDetail);
      return [errorObj, null];
    }
    const updateResult = await storesCol.updateOne(
      this.userQueries.findById(storeId),
      this.userQueries.removeUser(userId),
    );
    const result = (updateResult?.result?.nModified > 0);
    return [null, { result }];
  }

  async addThirdPartyUser(reqData) {
    const { thirdPartyId, userId } = reqData;
    const thirdCol = this.getDb().collection(THIRDPARTY_COLLECTION);
    const thirdParty = await thirdCol.findOne(this.userQueries.findById(thirdPartyId));
    if (!thirdParty) {
      const errorDetail = `Tercero con Id ${thirdPartyId} no encontrado`;
      const errorObj = this.errMgr.get(moduleErrors.store.notFound, errorDetail);
      return [errorObj, null];
    }
    const updateResult = await thirdCol.updateOne(
      this.userQueries.findById(thirdPartyId),
      this.userQueries.addUser(userId),
    );
    const result = (updateResult?.result?.nModified > 0);
    return [null, { result }];
  }

  async removeThirdPartyUser(reqData) {
    const { thirdPartyId, userId } = reqData;
    const thirdCol = this.getDb().collection(THIRDPARTY_COLLECTION);
    const thirdParty = await thirdCol.findOne(this.userQueries.findById(thirdPartyId));
    if (!thirdParty) {
      const errorDetail = `Tercero con Id ${thirdPartyId} no encontrado`;
      const errorObj = this.errMgr.get(moduleErrors.store.notFound, errorDetail);
      return [errorObj, null];
    }
    const updateResult = await thirdCol.updateOne(
      this.userQueries.findById(thirdPartyId),
      this.userQueries.removeUser(userId),
    );
    const result = (updateResult?.result?.nModified > 0);
    return [null, { result }];
  }
}

module.exports = UserManager;
